==> haskell-lrucache-1.2.0.0-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lrucache.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lrucache
version: 1.2.0.0
id: lrucache-1.2.0.0-3LnsSXRg8v3DqFXqRAnouf
key: lrucache-1.2.0.0-3LnsSXRg8v3DqFXqRAnouf
license: BSD3
copyright: Carl Howells, 2010-2015
maintainer: chowells79@gmail.com
stability: Experimental
homepage: http://github.com/chowells79/lrucache
synopsis: a simple, pure LRU cache
description:
    This package contains a simple, pure LRU cache, implemented in
    terms of "Data.Map".
    .
    It also contains a mutable IO wrapper providing atomic updates to
    an LRU cache.
category: Data
author: Carl Howells
exposed: True
indefinite: False
exposed-modules:
    Data.Cache.LRU Data.Cache.LRU.IO Data.Cache.LRU.IO.Internal
    Data.Cache.LRU.Internal
abi: 0da212df85bf674efd916ab63a7d0af2
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/lrucache-1.2.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/lrucache-1.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/lrucache-1.2.0.0
hs-libraries: HSlrucache-1.2.0.0-3LnsSXRg8v3DqFXqRAnouf
depends:
    base-4.10.1.0 containers-0.5.10.2
    contravariant-1.4.1-13GQTLKwlDGjgc4QL8uyp
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             contravariant-1.4.1-13GQTLKwlDGjgc4QL8uyp=d03fb164c8034777ff5b0827082d2495
haddock-interfaces: /usr/share/doc/haskell-lrucache/html/lrucache.haddock
haddock-html: /usr/share/doc/haskell-lrucache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lrucache-1.2.0.0-25-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lrucache.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lrucache
version: 1.2.0.0
id: lrucache-1.2.0.0-4Y80DRitIu690ZjLM3JuKK
key: lrucache-1.2.0.0-4Y80DRitIu690ZjLM3JuKK
license: BSD3
copyright: Carl Howells, 2010-2015
maintainer: chowells79@gmail.com
stability: Experimental
homepage: http://github.com/chowells79/lrucache
synopsis: a simple, pure LRU cache
description:
    This package contains a simple, pure LRU cache, implemented in
    terms of "Data.Map".
    .
    It also contains a mutable IO wrapper providing atomic updates to
    an LRU cache.
category: Data
author: Carl Howells
exposed: True
indefinite: False
exposed-modules:
    Data.Cache.LRU Data.Cache.LRU.IO Data.Cache.LRU.IO.Internal
    Data.Cache.LRU.Internal
abi: aa0bdc56cbfb5cd2b163f94541ca5132
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/lrucache-1.2.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/lrucache-1.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/lrucache-1.2.0.0
hs-libraries: HSlrucache-1.2.0.0-4Y80DRitIu690ZjLM3JuKK
depends:
    base-4.10.1.0 containers-0.5.10.2
    contravariant-1.4.1-7cEYjzgkYgPFdXWpdMNGgr
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             contravariant-1.4.1-7cEYjzgkYgPFdXWpdMNGgr=5e2c57f6d5adae18dd0e94f3a1c17f3b
haddock-interfaces: /usr/share/doc/haskell-lrucache/html/lrucache.haddock
haddock-html: /usr/share/doc/haskell-lrucache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
